# sqlalchemy-lazy-way

![pyversions](https://img.shields.io/badge/python%20-3.7%2B-blue.svg)
![celery](https://img.shields.io/badge/celery-4.2.0-4BC51D.svg)
![pypi](https://img.shields.io/pypi/v/nine.svg)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-ff69b4.svg)](https://github.com/twocucao/YaDjangoWeb/issues)

## 目的

使用 sqlalchemy 之后，很多查询写起来特别啰嗦。为了在提高效率的基础上能挽留点头发 , 于是开了这个项目。

1. Django Like Query
2. Common Utils

## Get Started

```bash
brew install python3
```

## 技术栈

 - Python 3.7.0

## 许可

mit

## Credits

- smart_query ported from https://github.com/mitsuhiko/sqlalchemy-django-query/blob/master/tests.py

